@@ -3,6 +3,7 @@ from .start_branch import StartBranch
 from .set_template import SetTemplate
 from .unset_template import UnsetTemplate
 from .finish_branch import FinishBranch
+from .cleanup import Cleanup
 
 #: Maps command names to WorkflowBase subclasses
 commands = {
@@ -10,6 +11,7 @@ commands = {
     FinishBranch.command: FinishBranch,
     SetTemplate.command: SetTemplate,
     UnsetTemplate.command: UnsetTemplate,
+    Cleanup.command: Cleanup,
 }
 
 
